numpy.matrix
============

.. currentmodule:: numpy

.. autoclass:: matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         matrix.__init__
         matrix.all
         matrix.any
         matrix.argmax
         matrix.argmin
         matrix.argsort
         matrix.astype
         matrix.byteswap
         matrix.choose
         matrix.clip
         matrix.compress
         matrix.conj
         matrix.conjugate
         matrix.copy
         matrix.cumprod
         matrix.cumsum
         matrix.diagonal
         matrix.dot
         matrix.dump
         matrix.dumps
         matrix.fill
         matrix.flatten
         matrix.getA
         matrix.getA1
         matrix.getH
         matrix.getI
         matrix.getT
         matrix.getfield
         matrix.item
         matrix.itemset
         matrix.max
         matrix.mean
         matrix.min
         matrix.newbyteorder
         matrix.nonzero
         matrix.prod
         matrix.ptp
         matrix.put
         matrix.ravel
         matrix.repeat
         matrix.reshape
         matrix.resize
         matrix.round
         matrix.searchsorted
         matrix.setasflat
         matrix.setfield
         matrix.setflags
         matrix.sort
         matrix.squeeze
         matrix.std
         matrix.sum
         matrix.swapaxes
         matrix.take
         matrix.tofile
         matrix.tolist
         matrix.tostring
         matrix.trace
         matrix.transpose
         matrix.var
         matrix.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         matrix.A
         matrix.A1
         matrix.H
         matrix.I
         matrix.T
         matrix.base
         matrix.ctypes
         matrix.data
         matrix.dtype
         matrix.flags
         matrix.flat
         matrix.imag
         matrix.itemsize
         matrix.nbytes
         matrix.ndim
         matrix.real
         matrix.shape
         matrix.size
         matrix.strides

